@@ -1,7 +1,7 @@
 /*
  * frogr-main-view.c -- Main view for the application
  *
- * Copyright (C) 2009-2017 Mario Sanchez Prada
+ * Copyright (C) 2009-2018 Mario Sanchez Prada
  *           (C) 2011 Joaquim Rocha
  * Authors:
  *   Joaquim Rocha <jrocha@igalia.com>
@@ -47,7 +47,6 @@
 
 /* Path relative to the application data dir */
 #define UI_MAIN_VIEW_FILE "/gtkbuilder/frogr-main-view.ui"
-#define UI_APP_MENU_FILE "/gtkbuilder/frogr-app-menu.ui"
 #define UI_CONTEXT_MENU_FILE "/gtkbuilder/frogr-context-menu.ui"
 #if USE_HEADER_BAR
 #define UI_MENU_BUTTON_FILE "/gtkbuilder/frogr-menu-button.ui"
@@ -105,6 +104,9 @@ struct _FrogrMainView {
 #if USE_HEADER_BAR
   GtkWidget *header_bar;
 #endif
+  GtkWidget *main_stack;
+  GtkWidget *scrolled_window;
+  GtkWidget *empty_state_vbox;
   GtkWidget *icon_view;
   GtkWidget *status_bar;
 
@@ -120,7 +122,7 @@ struct _FrogrMainView {
   guint sb_context_id;
 
   GtkBuilder *builder;
-  GMenuModel *app_menu;
+  GMenuModel *menu_model;
 };
 
 G_DEFINE_TYPE (FrogrMainView, frogr_main_view, GTK_TYPE_APPLICATION_WINDOW)
@@ -358,18 +360,11 @@ _initialize_ui (FrogrMainView *self)
   main_vbox = GTK_WIDGET (gtk_builder_get_object (builder, "main_window_vbox"));
   gtk_container_add (GTK_CONTAINER (self), main_vbox);
 
-  /* App menu */
-  full_path = g_strdup_printf ("%s/" UI_APP_MENU_FILE, frogr_util_get_app_data_dir ());
-  gtk_builder_add_from_file (builder, full_path, NULL);
-  g_free (full_path);
-
+  /* Load app menu entries */
   self->gtk_app = gtk_window_get_application (GTK_WINDOW (self));
   g_action_map_add_action_entries (G_ACTION_MAP (self->gtk_app),
                                    app_entries, G_N_ELEMENTS (app_entries),
                                    self);
-  self->app_menu = G_MENU_MODEL (gtk_builder_get_object (builder, "app-menu"));
-  gtk_application_set_app_menu (self->gtk_app, self->app_menu);
-
 #if USE_HEADER_BAR
   /* Header_Bar and main vertical box below*/
   _initialize_header_bar (self);
@@ -380,6 +375,10 @@ _initialize_ui (FrogrMainView *self)
   gtk_window_set_hide_titlebar_when_maximized (GTK_WINDOW (self), TRUE);
 #endif
 
+  self->main_stack = GTK_WIDGET (gtk_builder_get_object (builder, "main_stack"));
+  self->scrolled_window = GTK_WIDGET (gtk_builder_get_object (builder, "scrolled_window"));
+  self->empty_state_vbox = GTK_WIDGET (gtk_builder_get_object (builder, "empty_state_vbox"));
+
   icon_view = GTK_WIDGET (gtk_builder_get_object (builder, "icon_view"));
   self->icon_view = icon_view;
 
@@ -440,6 +439,7 @@ _initialize_ui (FrogrMainView *self)
 
   progress_vbox = gtk_message_dialog_get_message_area (GTK_MESSAGE_DIALOG (progress_dialog));
   gtk_container_add (GTK_CONTAINER (progress_vbox), progress_bar);
+  gtk_widget_show (GTK_WIDGET (progress_bar));
 
   gtk_widget_hide (progress_dialog);
   self->progress_dialog = progress_dialog;
@@ -578,7 +578,6 @@ extract_accels_from_menu (GMenuModel     *model,
 
 static void _initialize_header_bar (FrogrMainView *self)
 {
-  GMenuModel *menu_model = NULL;
   GtkWidget *toolbar = NULL;
   GtkWidget *header_item = NULL;
   GtkWidget *menu = NULL;
@@ -595,19 +594,19 @@ static void _initialize_header_bar (FrogrMainView *self)
   /* First create the left side buttons */
 
   _add_item_to_header_bar (self, HEADER_BAR_POSITION_START, "win.open-project", "document-open-symbolic", _("Open"), _("Open Existing Project"), "<Primary>o");
-  _add_item_to_header_bar (self, HEADER_BAR_POSITION_START, "win.add-pictures", "list-add-symbolic", _("Add"), _("Add Elements"), "<Primary>l");
-  _add_item_to_header_bar (self, HEADER_BAR_POSITION_START, "win.remove-pictures", "list-remove-symbolic", _("Remove"), _("Remove Elements"), "Delete");
-  _add_item_to_header_bar (self, HEADER_BAR_POSITION_START, "win.upload-all", "document-send-symbolic", _("Upload"), _("Upload All"), "<Primary>u");
+  _add_item_to_header_bar (self, HEADER_BAR_POSITION_START, "win.add-pictures", "list-add-symbolic", _("Add"), _("Add"), "<Primary>l");
+  _add_item_to_header_bar (self, HEADER_BAR_POSITION_START, "win.remove-pictures", "list-remove-symbolic", _("Remove"), _("Remove"), "Delete");
+  _add_item_to_header_bar (self, HEADER_BAR_POSITION_START, "win.upload-all", "document-send-symbolic", _("Upload"), _("Upload"), "<Primary>u");
 
   /* Menu button and its associated menu */
 
   full_path = g_strdup_printf ("%s/" UI_MENU_BUTTON_FILE, frogr_util_get_app_data_dir ());
   gtk_builder_add_from_file (self->builder, full_path, NULL);
 
-  menu_model = G_MENU_MODEL (gtk_builder_get_object (self->builder, "menu-button"));
-  extract_accels_from_menu (menu_model, self->gtk_app);
+  self->menu_model = G_MENU_MODEL (gtk_builder_get_object (self->builder, "menu-button"));
+  extract_accels_from_menu (self->menu_model, self->gtk_app);
 
-  menu = gtk_menu_new_from_model (menu_model);
+  menu = gtk_menu_new_from_model (self->menu_model);
   gtk_widget_set_halign (menu, GTK_ALIGN_END);
 
   g_action_map_add_action_entries (G_ACTION_MAP (self),
@@ -680,8 +679,8 @@ static void _initialize_menubar_and_toolbar (FrogrMainView *self)
                                    win_entries, G_N_ELEMENTS (win_entries),
                                    self);
 
-  gtk_application_set_menubar (gtk_window_get_application (GTK_WINDOW (self)),
-                               G_MENU_MODEL (gtk_builder_get_object (self->builder, "menu-bar")));
+  self->menu_model = G_MENU_MODEL (gtk_builder_get_object (self->builder, "menu-bar"));
+  gtk_application_set_menubar (gtk_window_get_application (GTK_WINDOW (self)), self->menu_model);
   gtk_application_window_set_show_menubar (GTK_APPLICATION_WINDOW (self), TRUE);
 
   /* Toolbar */
@@ -691,10 +690,10 @@ static void _initialize_menubar_and_toolbar (FrogrMainView *self)
   toolbar_items[0] = _create_toolbar_item ("win.open-project", "document-open", _("Open"), _("Open Existing Project"));
   toolbar_items[1] = _create_toolbar_item ("win.save-project", "document-save", _("Save"), _("Save Current Project"));
   toolbar_items[2] = gtk_separator_tool_item_new ();
-  toolbar_items[3] = _create_toolbar_item ("win.add-pictures", "list-add", _("Add"), _("Add Elements"));
-  toolbar_items[4] = _create_toolbar_item ("win.remove-pictures", "list-remove", _("Remove"), _("Remove Elements"));
+  toolbar_items[3] = _create_toolbar_item ("win.add-pictures", "list-add", _("Add"), _("Add"));
+  toolbar_items[4] = _create_toolbar_item ("win.remove-pictures", "list-remove", _("Remove"), _("Remove"));
   toolbar_items[5] = gtk_separator_tool_item_new ();
-  toolbar_items[6] = _create_toolbar_item ("win.upload-all", "go-up", _("Upload"), _("Upload All"));
+  toolbar_items[6] = _create_toolbar_item ("win.upload-all", "go-up", _("Upload"), _("Upload"));
 
   for (i = 0; i < G_N_ELEMENTS (toolbar_items); ++i)
     gtk_toolbar_insert (GTK_TOOLBAR (toolbar), toolbar_items[i], i);
@@ -962,7 +961,10 @@ _populate_accounts_submenu (FrogrMainView *self)
   FrogrAccount *account = NULL;
   GMenuItem *accounts_menu;
   GMenuItem *menu_item = NULL;
-  GMenuModel *submenu = NULL;
+#if !USE_HEADER_BAR
+  GMenuModel *file_submenu = NULL;
+#endif
+  GMenuModel *accounts_submenu = NULL;
   GMenuModel *section = NULL;
   GSList *accounts = NULL;
   GSList *item = NULL;
@@ -970,7 +972,13 @@ _populate_accounts_submenu (FrogrMainView *self)
   gchar *action_str = NULL;
 
   /* Remove a previous submenu if present (it will be regenerated later) */
-  section = g_menu_model_get_item_link (self->app_menu, 0, G_MENU_LINK_SECTION);
+#if USE_HEADER_BAR
+  section = g_menu_model_get_item_link (self->menu_model, 0, G_MENU_LINK_SECTION);
+#else
+  file_submenu = g_menu_model_get_item_link (self->menu_model, 0, G_MENU_LINK_SUBMENU);
+  section = g_menu_model_get_item_link (file_submenu, 0, G_MENU_LINK_SECTION);
+#endif
+
   if (g_menu_model_get_n_items (G_MENU_MODEL (section)) > 1)
     g_menu_remove (G_MENU (section), 1);
 
@@ -978,7 +986,7 @@ _populate_accounts_submenu (FrogrMainView *self)
   if (!g_slist_length (accounts))
     return;
 
-  submenu = G_MENU_MODEL (g_menu_new ());
+  accounts_submenu = G_MENU_MODEL (g_menu_new ());
   for (item = accounts; item; item = g_slist_next (item))
     {
       account = FROGR_ACCOUNT (item->data);
@@ -989,7 +997,7 @@ _populate_accounts_submenu (FrogrMainView *self)
       username = frogr_account_get_username (account);
       action_str = g_strdup_printf ("app.login-as::%s", username);
       menu_item = g_menu_item_new (username, action_str);;
-      g_menu_append_item (G_MENU (submenu), menu_item);
+      g_menu_append_item (G_MENU (accounts_submenu), menu_item);
       g_free (action_str);
 
       if (frogr_account_is_active (account))
@@ -1001,7 +1009,7 @@ _populate_accounts_submenu (FrogrMainView *self)
     }
 
   /* Create the submenu and insert it in the right section */
-  accounts_menu = g_menu_item_new_submenu (_("Accounts"), submenu);
+  accounts_menu = g_menu_item_new_submenu (_("Accounts"), accounts_submenu);
   g_menu_insert_item (G_MENU (section), 1, accounts_menu);
 }
 
@@ -1494,7 +1502,7 @@ _open_project_dialog (FrogrMainView *self)
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-  gtk_widget_show_all (dialog);
+  gtk_widget_show (dialog);
 }
 
 static void
@@ -1563,7 +1571,7 @@ _save_project_as_dialog (FrogrMainView *self)
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-  gtk_widget_show_all (dialog);
+  gtk_widget_show (dialog);
 }
 
 static void
@@ -1644,7 +1652,7 @@ _load_pictures_dialog (FrogrMainView *self)
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-  gtk_widget_show_all (dialog);
+  gtk_widget_show (dialog);
 }
 
 static gboolean
@@ -1989,8 +1997,16 @@ _model_picture_removed (FrogrController *controller,
 static void
 _model_changed (FrogrController *controller, gpointer data)
 {
+  FrogrMainView *self = FROGR_MAIN_VIEW (data);
+
   /* Reflect that the current state is 'dirty' in the title */
-  _update_window_title (FROGR_MAIN_VIEW (data), TRUE);
+  _update_window_title (self, TRUE);
+
+  /* Select the right page of the stack */
+  if (frogr_model_n_pictures (self->model) > 0)
+    gtk_stack_set_visible_child (GTK_STACK (self->main_stack), self->scrolled_window);
+  else
+    gtk_stack_set_visible_child (GTK_STACK (self->main_stack), self->empty_state_vbox);
 }
 
 static void
@@ -2363,7 +2379,7 @@ frogr_main_view_show_progress (FrogrMainView *self, const gchar *title, const gc
   gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (self->progress_bar), 0.0);
   gtk_progress_bar_set_show_text (GTK_PROGRESS_BAR (self->progress_bar), FALSE);
 
-  gtk_widget_show_all (GTK_WIDGET (self->progress_dialog));
+  gtk_widget_show (GTK_WIDGET (self->progress_dialog));
   gtk_window_present (GTK_WINDOW (self->progress_dialog));
 }
 
