@@ -1,7 +1,7 @@
 /*
  * main.c -- Main file and initialization
  *
- * Copyright (C) 2009-2015 Mario Sanchez Prada
+ * Copyright (C) 2009-2017 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -25,7 +25,7 @@
 
 #include <config.h>
 #include <glib/gi18n.h>
-#ifdef HAVE_GSTREAMER
+#if HAVE_GSTREAMER
 #include <gst/gst.h>
 #endif
 #include <libxml/parser.h>
@@ -40,18 +40,15 @@ GCRY_THREAD_OPTION_PTHREAD_IMPL;
 int
 main (int argc, char **argv)
 {
-  FrogrController *controller = NULL;
+  g_autoptr(FrogrController) controller = NULL;
   int status;
-#ifdef HAVE_GSTREAMER
-  GError *error = NULL;
+#if HAVE_GSTREAMER
+  g_autoptr(GError) error = NULL;
 
   /* Initialize gstreamer before using any other GLib function */
   gst_init_check (&argc, &argv, &error);
   if (error)
-    {
-      DEBUG ("Gstreamer could not be initialized: %s", error->message);
-      g_error_free (error);
-    }
+    DEBUG ("Gstreamer could not be initialized: %s", error->message);
 #endif
 
 #if GCRYPT_VERSION_NUMBER < 0x010600
@@ -72,13 +69,12 @@ main (int argc, char **argv)
   xmlInitParser ();
 
   /* Initialize internationalization */
-  bindtextdomain (GETTEXT_PACKAGE, frogr_util_get_locale_dir ());
+  bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
   controller = frogr_controller_get_instance ();
   status = frogr_controller_run_app (controller, argc, argv);
-  g_object_unref (controller);
 
   /* cleanup libxml2 library */
   xmlCleanupParser();
